<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ViewToolBars</name>
    <message>
        <source>&amp;Toolbars</source>
        <translation type="vanished">ツールバー(&amp;T)</translation>
    </message>
    <message>
        <location filename="../ViewToolBarsPostInit.js" line="+6"/>
        <source>&amp;Toolbars and Widgets</source>
        <translation>ツールバーとウィジェット</translation>
    </message>
</context>
</TS>
